@@ -5,10 +5,10 @@
 #include <QVector>
 #include <QHash>
 #include <QPainterPath>
-#include "vector_tile.pb.h"
+#include "data.h"
 
 
-typedef QHash<QString, google::protobuf::uint32> KeyHash;
+typedef QHash<QByteArray, quint32> KeyHash;
 
 class PBF
 {
@@ -19,17 +19,17 @@ public:
 	{
 	public:
 		Feature() : _data(0), _layer(0) {}
-		Feature(const vector_tile::Tile_Feature *data, const Layer *layer)
+		Feature(const Data::Feature *data, const Layer *layer)
 		  : _data(data), _layer(layer) {}
 
-		const QVariant *value(const QString &key) const;
-		vector_tile::Tile_GeomType type() const {return _data->type();}
+		const QVariant *value(const QByteArray &key) const;
+		Data::GeomType type() const {return _data->type;}
 		QPainterPath path(const QSizeF &factor) const;
 
 		friend bool operator<(const Feature &f1, const Feature &f2);
 
 	private:
-		const vector_tile::Tile_Feature *_data;
+		const Data::Feature *_data;
 		const Layer *_layer;
 	};
 
@@ -37,31 +37,30 @@ public:
 	{
 	public:
 
-		Layer(const vector_tile::Tile_Layer *data);
+		Layer(const Data::Layer *layer);
 
 		const QVector<Feature> &features() const {return _features;}
-		const QVector<QVariant> &values() const {return _values;}
+		const QVector<QVariant> &values() const {return _data->values;}
 		const KeyHash &keys() const {return _keys;}
-		const vector_tile::Tile_Layer *data() const {return _data;}
+		const Data::Layer *data() const {return _data;}
 
 	private:
-		const vector_tile::Tile_Layer *_data;
+		const Data::Layer *_data;
 		QVector<Feature> _features;
-		QVector<QVariant> _values;
 		KeyHash _keys;
 	};
 
 
-	PBF(const vector_tile::Tile &tile);
+	PBF(const Data &data);
 	~PBF();
 
-	const QHash<QString, Layer*> &layers() const {return _layers;}
+	const QHash<QByteArray, Layer*> &layers() const {return _layers;}
 
 private:
-	QHash<QString, Layer*> _layers;
+	QHash<QByteArray, Layer*> _layers;
 };
 
 inline bool operator<(const PBF::Feature &f1, const PBF::Feature &f2)
-  {return f1._data->id() < f2._data->id();}
+  {return f1._data->id < f2._data->id;}
 
 #endif // PBF_H
